@@ -6,31 +6,14 @@
 
 
 from optparse import OptionParser
-
-import html2fo
-import fo2xfc
-import fo2pdf
-
+from convert import Converter
 
 def convert(options, args):
 
     for fn in args:
-    
-        fo_filename = html2fo.html2fo(fn)
-
-        if options.format in ('rtf', 'odt', 'docx', 'wml'):
-            output_filename = fo2xfc.fo2xfc(fo_filename, options.format)
-
-        elif options.format == 'pdf':
-            output_filename = fo2pdf.fo2pdf(fo_filename)
-
-
-        else:
-            raise ValueError('Unsupported format %s' % options.format)
-
+        C = Converter(fn)
+        output_filename = C(options.format, output_filename=options.output_filename)
         print 'Generated file: %s' % output_filename
-
-
    
 
 def main():
