@@ -9,22 +9,30 @@ import sys
 
 from config import java
 from util import newTempfile, runcmd
+from logger import LOG
 
 xinc_home = os.environ.get('XINC_HOME')
-if not xinc_home:
-    raise ValueError('$XINC_HOME not set')
 
-if not os.path.exists(xinc_home):
-    raise IOError('$XINC_HOME=%s does not exist' % xinc_home)
+def _check_xinc():
+    if not xinc_home:
+        LOG.error('$XINC_HOME not set')
+        return False
 
+    if not os.path.exists(xinc_home):
+        LOG.error('$XINC_HOME=%s does not exist' % xinc_home)
+        return False
 
-def fo2pdf(fo_filename):
+    return True        
+
+xinc_available = _check_xinc()
+
+def fo2pdf(fo_filename, output_filename=None):
     """ Convert a FO file to PDF using XINC """
 
+    if not output_filename:
+        output_filename = newTempfile(suffix='.pdf')
 
-    output_filename = newTempfile(suffix='.pdf')
     cmd = '"%s/bin/unix/xinc" -fo "%s" -pdf "%s"' % (xinc_home, fo_filename, output_filename)
-
     status, output = runcmd(cmd)
     if status != 0:
         raise RuntimeError('Error executing: %s' % cmd)
