@@ -9,16 +9,25 @@ import sys
 
 from config import java
 from util import newTempfile, runcmd
+from logger import LOG
 
 xfc_dir = os.environ.get('XFC_DIR')
-if not xfc_dir:
-    raise ValueError('$XFC_DIR not set')
-
-if not os.path.exists(xfc_dir):
-    raise IOError('$XFC=%s does not exist' % xfc_dir)
 
 
-def fo2xfc(fo_filename, format='rtf'):
+def _check_xfc():
+    if not xfc_dir:
+        LOG.error('$XFC_DIR not set')
+        return False
+
+    if not os.path.exists(xfc_dir):
+        LOG.error('$XFC=%s does not exist' % xfc_dir)
+        return False
+
+    return True
+
+xfc_available = _check_xfc()
+
+def fo2xfc(fo_filename, format='rtf', output_filename=None):
     """ Convert a FO file to some format support 
         through XFC-4.0.
     """
@@ -26,7 +35,8 @@ def fo2xfc(fo_filename, format='rtf'):
     if not format in ('rtf', 'docx', 'wml', 'odt'):
         raise ValueError('Unsupported format: %s' % format)
 
-    output_filename = newTempfile(suffix='.%s' % format)
+    if not output_filename:
+        output_filename = newTempfile(suffix='.%s' % format)
     cmd = '"%s/fo2%s" "%s" "%s"' % (xfc_dir, format, fo_filename, output_filename)
 
     status, output = runcmd(cmd)
