@@ -18,7 +18,6 @@ dirname = os.path.dirname(__file__)
 def tidyhtml(filename):
 
     html = open(filename, 'rb').read()
-
     nerrors, nwarnings, html, errordata = mx.Tidy.tidy(html,
                                                        drop_empty_paras=0,
                                                        add_xml_decl=1,
@@ -36,7 +35,6 @@ def html2fo(filename, language='en', country='en', tidy=True):
     if tidy:
         filename = tidyhtml(filename)
 
-
     fo_filename = newTempfile(suffix='.fo')
     csstoxslfo = os.path.abspath(os.path.join(dirname, 'lib', 'csstoxslfo', 'css2xslfo.jar'))
     if not os.path.exists(csstoxslfo):
@@ -49,7 +47,11 @@ def html2fo(filename, language='en', country='en', tidy=True):
     if status != 0:
         raise RuntimeError('Error executing: %s' % cmd)
 
+    # remove tidy-ed file
+    os.unlink(filename)
 
+    # remove some stuff from the generated FO file causing
+    # some conversion trouble either with XINC or XFC
     fo_text = open(fo_filename, 'rb').read()
 
     reg_s = '(footnote="reset")|'\
